stac.nonparametric_tests.nemenyi_multitest — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.nemenyi_multitest

`stac.nonparametric_tests.` `nemenyi_multitest`(ranks)

  Performs a Nemenyi post-hoc test using the pivot quantities obtained by a ranking test. Tests the hypothesis that the ranking of each pair of groups are different.

  Parameters: | pivots : dictionary_like A dictionary with format ‘groupname’:’pivotal quantity’
  Returns: | Comparions : array-like Strings identifier of each comparison with format ‘group_i vs group_j’ Z-values : array-like The computed Z-value statistic for each comparison. p-values : array-like The associated p-value from the Z-distribution wich depends on the index of the comparison Adjusted p-values : array-like The associated adjusted p-values wich can be compared with a significance level

  References

  Bonferroni-Dunn: O.J. Dunn, Multiple comparisons among means, Journal of the American Statistical Association 56 (1961) 52–64.

### Navigation

- index
- STAC Release Candidate documentation »